import i18n from 'sveltekit-i18n';

/**
 * A frozen object mapping locale identifiers to their respective locale codes.
 *
 * These values represent the supported languages in the application.
 * Used for validating user preferences and loading the correct translations.
 *
 * @readonly
 * @enum {string}
 */
export const SUPPORTED_LOCALES = Object.freeze({
  EN_US: 'en-US',
  PT_BR: 'pt-BR',
});

/** @type {import('sveltekit-i18n').Config} */
const config = {
  initLocale: navigator.language,
  fallbackLocale: SUPPORTED_LOCALES.PT_BR,
  loaders: [
    {
      locale: SUPPORTED_LOCALES.EN_US,
      key: 'header',
      loader: async () => (await import('./en-US/header.json')).default,
    },
    {
      locale: SUPPORTED_LOCALES.EN_US,
      key: 'footer',
      loader: async () => (await import('./en-US/footer.json')).default,
    },
    {
      locale: SUPPORTED_LOCALES.PT_BR,
      key: 'header',
      loader: async () => (await import('./pt-BR/header.json')).default,
    },
    {
      locale: SUPPORTED_LOCALES.PT_BR,
      key: 'footer',
      loader: async () => (await import('./pt-BR/footer.json')).default,
    },
  ],
};

export const { t, locale, locales, loading, loadTranslations } = new i18n(
  config,
);

locale.subscribe(($locale) => {
  if (typeof document !== 'undefined') {
    document.cookie = `locale=${$locale}; path=/; SameSite=Strict;`;
  }
});
